@@ -23,10 +23,15 @@ MONO_BEGIN_DECLS
 #define OPDEF(a,b,c,d,e,f,g,h,i,j) \
 	MONO_ ## a,
 
-typedef enum {
+#ifndef __MONO_METADATA_BASIC_BLOCK_H__
+typedef enum _MonoOpcodeEnum MonoOpcodeEnum;
+#endif
+
+enum _MonoOpcodeEnum {
+	MonoOpcodeEnum_Invalid = -1,
 #include "mono/cil/opcode.def"
 	MONO_CEE_LAST
-} MonoOpcodeEnum;
+};
 
 #undef OPDEF
 
@@ -41,23 +46,23 @@ enum {
 };
 
 enum {
-	MonoInlineNone,
-	MonoInlineType,
-	MonoInlineField,
-	MonoInlineMethod,
-	MonoInlineTok,
-	MonoInlineString,
-	MonoInlineSig,
-	MonoInlineVar,
-	MonoShortInlineVar,
-	MonoInlineBrTarget,
-	MonoShortInlineBrTarget,
-	MonoInlineSwitch,
-	MonoInlineR,
-	MonoShortInlineR,
-	MonoInlineI,
-	MonoShortInlineI,
-	MonoInlineI8
+	MonoInlineNone          = 0,
+	MonoInlineType          = 1,
+	MonoInlineField         = 2,
+	MonoInlineMethod        = 3,
+	MonoInlineTok           = 4,
+	MonoInlineString        = 5,
+	MonoInlineSig           = 6,
+	MonoInlineVar           = 7,
+	MonoShortInlineVar      = 8,
+	MonoInlineBrTarget      = 9,
+	MonoShortInlineBrTarget = 10,
+	MonoInlineSwitch        = 11,
+	MonoInlineR             = 12,
+	MonoShortInlineR        = 13,
+	MonoInlineI             = 14,
+	MonoShortInlineI        = 15,
+	MonoInlineI8            = 16,
 };
 
 typedef struct {
